From 83825a889f3aa71151130d1605560dc4a2e199d6 Mon Sep 17 00:00:00 2001
From: Craig Tiller <ctiller@google.com>
Date: Wed, 17 Aug 2022 09:25:12 -0700
Subject: [PATCH] [fixit] Loosen bounds on periodic update test (#30612)

---
 test/core/resource_quota/periodic_update_test.cc | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/test/core/resource_quota/periodic_update_test.cc b/test/core/resource_quota/periodic_update_test.cc
index 79fe69a1b06..c2afd93e278 100644
--- a/test/core/resource_quota/periodic_update_test.cc
+++ b/test/core/resource_quota/periodic_update_test.cc
@@ -60,12 +60,12 @@ TEST(PeriodicUpdateTest, SimpleTest) {
       ExecCtx exec_ctx;
       upd->Tick([&](Duration) { done = true; });
     }
-    // Ensure the time taken was between 1 and 1.5 seconds - we make a little
+    // Ensure the time taken was between 1 and 3 seconds - we make a little
     // allowance for the presumed inaccuracy of this type.
     {
       ExecCtx exec_ctx;
       EXPECT_GE(exec_ctx.Now() - start, Duration::Seconds(1));
-      EXPECT_LE(exec_ctx.Now() - start, Duration::Milliseconds(1500));
+      EXPECT_LE(exec_ctx.Now() - start, Duration::Seconds(3));
       start = exec_ctx.Now();
     }
   }
@@ -101,11 +101,11 @@ TEST(PeriodicUpdate, ThreadTest) {
   for (auto& th : threads) {
     th.join();
   }
   // Ensure our ten cycles took at least 10 seconds, and no more than 15.
   {
     ExecCtx exec_ctx;
     EXPECT_GE(exec_ctx.Now() - start, Duration::Seconds(10));
-    EXPECT_LE(exec_ctx.Now() - start, Duration::Seconds(15));
+    EXPECT_LE(exec_ctx.Now() - start, Duration::Seconds(30));
   }
 }
@@ -101,11 +101,11 @@ TEST(PeriodicUpdate, ThreadTest) {
     th.join();
   }
-  // Ensure our ten cycles took at least 10 seconds, and no more than 15.
+  // Ensure our ten cycles took at least 10 seconds, and no more than 30.
   {
     ExecCtx exec_ctx;